This is the list of Archai authors for copyright purposes.

This does not necessarily list everyone who has contributed code, since in some cases, their employer may be the copyright holder.  To see the full list of contributors, see the revision history in source control.

- [Shital Shah](http://www.shitalshah.com)
- [Debadeepta Dey](https://www.debadeepta.com)
- [Gustavo de Rosa](https://www.microsoft.com/en-us/research/people/gderosa)
- Caio Mendes
- [Piero Kauffmann](https://www.microsoft.com/en-us/research/people/pkauffmann)
- [Chris Lovett](https://lovettsoftware.com)
- Allie Del Giorno
- Mojan Javaheripi
- [Ofer Dekel](https://www.microsoft.com/en-us/research/people/oferd)